@@ -66,25 +66,33 @@ class FfmpegProcess:
         try:
             while self._process.poll() is None:
                 if self._can_get_duration:
-                    line = self._process.stdout.readline().decode("utf-8")
-                    if "out_time_ms" in line:
-                        seconds_processed = int(line.strip()[12:]) / 1_000_000
-
+                    ffmpeg_output = self._process.stdout.readline().decode()
                     # A progress handler was not specified. Use tqdm to show a progress bar.
                     if progress_handler is None:
-                        seconds_increase = seconds_processed - previous_seconds_processed
-                        progress_bar.update(seconds_increase)
-                        previous_seconds_processed = seconds_processed
+                        if "out_time_ms" in ffmpeg_output:
+                            seconds_processed = int(ffmpeg_output.strip()[12:]) / 1_000_000
+                            seconds_increase = seconds_processed - previous_seconds_processed
+                            progress_bar.update(seconds_increase)
+                            previous_seconds_processed = seconds_processed
                     # A progress handler was specified.
                     else:
-                        percentage = round((seconds_processed / self._duration_secs) * 100, 1)
+                        if "out_time_ms" in ffmpeg_output:
+                            seconds_processed = int(ffmpeg_output.strip()[12:]) / 1_000_000
+                            percentage = round((seconds_processed / self._duration_secs) * 100, 1)
+
                         if "speed" in ffmpeg_output:
                             speed = ffmpeg_output.split("=")[1].strip()
-                            speed = 0 if " " in speed or "N/A" in speed else float(speed[:-1])
-                            if speed != 0:
+                            if " " in speed or "N/A" in speed:
+                                speed = None
+                            else:
+                                speed = float(speed[:-1])
+
+                            if speed:
                                 eta = (file_duration - secs) / speed
                                 progress_handler(percentage, f"{speed}x", eta)
 
+            print(f"Done! Check out {ffmpeg_output_file} to see the FFmpeg output.")
+
         except KeyboardInterrupt:
             progress_bar.close()
             self._process.kill()
